@@ -78,6 +78,20 @@ def search_contacts(property_names, filters, after=None):
   return result
 
 
+def read_contacts_batch(properties, inputs, id_property=None):
+  post_url = f"{BASE_URL}crm/v3/objects/contacts/batch/read"
+  post_body = {
+      'properties': properties,
+      'inputs': contacts
+  }
+  if id_property is not None:
+    post_body['idProperty'] = id_property
+  result = post(post_url, HEADERS, json.dumps(post_body))
+  if not Utils.is_success(result['status_code']):
+    raise Exception(f"Failed to read contacts. Result: {result}")
+  return result
+
+
 def get_contact(contact_id, property_names=None, associations=None):
   post_url = f"{BASE_URL}crm/v3/objects/contacts/{contact_id}?archived=false"
   if property_names:
